<?php
	/*
	functions
	***************************/

	if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
	
	
	
	add_action( 'post_comment_status_meta_box-options', 'wprsanony_anonymous_reviews_checkbox' );
	/*
 		Print a checkbox into the comment status metabox,
		this is used to allow user reviews when comments are not allowed for visitors in discussion settings.

		@wp-hook post_comment_status_meta_box-options
		@param object $post
		@return void
		@since 1.0
		*/
	function wprsanony_anonymous_reviews_checkbox( $post ) {
		
		$key = '_wprs_post_allow_anonymous_reviews';
		$current = get_post_meta( $post->ID, $key, TRUE );
 
		printf(
				'<br /><label for="%1$s">
				<input type="checkbox" id="%1$s" name="%1$s" class="selectit" %2$s/> %3$s
				</label>',
				$key,
				checked( 1, $current, FALSE ),
				apply_filters( 'acpp_metabox_label', __('Allow anonymous user reviews.', 'wprs') )
			);
	
	}
	
 
	add_action( 'save_post', 'wprsanony_anonymous_reviews_checkbox_save' );
	/*
		Save the checkbox value as number

		@wp-hook save_post
		@param int $post_id
		@param object $post
		@return void
		@since 1.0
		*/
	function wprsanony_anonymous_reviews_checkbox_save( $post_id, $post = '' ) {
		
		
		// AJAX autosave
		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) return;
 
		// Some other POST request
		if ( ! isset ( $_POST['post_type'] ) ) return;
 
		// Missing capability
		if ( ! current_user_can( 'edit_' . $_POST['post_type'], $post_id ) ) return;
 
		$key = '_wprs_post_allow_anonymous_reviews';
 		
		// Checkbox successfully clicked
		if ( isset ( $_POST[ $key ] ) and 'on' === strtolower( $_POST[ $key ] ) ) return update_post_meta( $post_id, $key, 1 );
 
		// Checkbox deselected
		delete_post_meta( $post_id, $key );
		
	}
 

	add_filter( 'pre_option_comment_registration', 'wprsanony_anonymous_reviews_reg_filter' );
	/*
		Trick the registration checks on front-end

		Important: If we return FALSE, the filter will be effectively ignored.
		It has to be any other value.

		@wp-hook pre_option_comment_registration
		@return bool|int
		@since 1.0
		*/
	function wprsanony_anonymous_reviews_reg_filter() {

		if ( is_admin() ) return FALSE;
 
		$key = '_wprs_post_allow_anonymous_reviews';
		$post_id = 0;
 
		// Only available on wp-comments-post.php, not on regular post pages.
		if ( isset( $_POST['comment_post_ID'] ) ) $post_id = (int) $_POST['comment_post_ID'];
 
		//
		$post = get_post( $post_id );
		$open = get_post_meta( $post->ID, $key, TRUE );
 
		if ( 1 == $open ) return 0;
 
		return FALSE;
		
	}
	
	
	add_filter('comment_form_default_fields', 'wprsanony_alter_comment_form_fields');
	/*
		alter comment form fields
		@since 1.0
		*/
	function wprsanony_alter_comment_form_fields($fields) {
		
		// get options
		$options = get_option('wprsanony_options');

		$commenter = wp_get_current_commenter();
		$req = get_option( 'require_name_email' );
		$aria_req = ( $req ? " aria-required='true'" : '' );
		$author_req = ( $req ? __('Name', 'wprs-anonymous') . '<span class="required">*</span>' : __('Name (Optional)', 'wprs-anonymous') );
		$email_req = ( $req ? __('Email', 'wprs-anonymous') . '<span class="required">*</span>' : __('Email (Optional)', 'wprs-anonymous') );

		// Modify Name Field and show that it's Optional 
		$fields['author'] = '<p class="comment-form-author">' . '<label for="author">' . $author_req . '</label> ' . '<input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30"' . $aria_req . ' /></p>';

		// Modify Email Field and show that it's Optional
		$fields['email'] = '<p class="comment-form-email"><label for="email">' . $email_req  . '</label> ' . '<input id="email" name="email" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) . '" size="30"' . $aria_req . ' /></p>'; 
		
		
		//$fields['comment_notes_before'] = '';
		
		if ( isset($options['wprsanony_chk_hide_name']) ) $fields['author'] = '';
		if ( isset($options['wprsanony_chk_hide_email']) ) $fields['email'] = '';
		
		// remove the website URL from comment form. 	  
		if ( ! $req )  $fields['url'] = '';

		return $fields;
		
	}


	
	add_filter('get_comment_author', 'wprsanony_replace_anonymous');
	/* 
		replace Anonymous word
		@since 1.0
		*/
	function wprsanony_replace_anonymous($name) {
		
		// get options
		$options = get_option('wprsanony_options');
		
		// check option value
		$other_word = isset($options['wprsanony_other_word']) ? $options['wprsanony_other_word'] : 'Anonymous';
		
		// replace 'Anonymous' with another word if is set within the add-on settings
		if (isset($options['wprsanony_other_word'])) {
			$name = str_replace('Anonymous', $other_word, $name);
		}
		
		return $name;
		
	}
	
	
	add_filter('get_comment_author', 'wprsanony_replace_name_with_anonymous');
	/* 
		replace all names with Anonymous word
		@since 1.1
		*/
	function wprsanony_replace_name_with_anonymous($name) {
		
		// get options
		$options = get_option('wprsanony_options');
		
		// check option value
		$other_word = isset($options['wprsanony_other_word']) ? $options['wprsanony_other_word'] : 'Anonymous';
		
		// replace name with 'Anonymous' or another word if is set within the add-on settings
		if ( isset($options['wprsanony_other_word']) && isset($options['wprsanony_chk_all_names']) !='' )  $name = $other_word;
		
		return $name;
		
	}
	
	
	add_filter( 'comment_form_defaults', 'wprsanony_remove_comment_notes_before' );
	/*
		remove comment notes before
		@since 1.0
		*/
	function wprsanony_remove_comment_notes_before($defaults){
		
		$defaults['comment_notes_before'] = '';
		
		return $defaults;
	}

